-- Copyright 2023 Lennart Augustsson
-- See LICENSE file for full license.
module Data.Maybe_Type(module Data.Maybe_Type) where
import qualified Prelude()              -- do not import Prelude

data Maybe a = Nothing | Just a
  deriving ()  -- avoid deriving Typeable
